# -*- coding: utf-8 -*-
# Copyright 2022 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from google.cloud.clouddms_v1 import gapic_version as package_version

__version__ = package_version.__version__


from .services.data_migration_service import (
    DataMigrationServiceAsyncClient,
    DataMigrationServiceClient,
)
from .types.clouddms import (
    ApplyConversionWorkspaceRequest,
    CommitConversionWorkspaceRequest,
    ConvertConversionWorkspaceRequest,
    CreateConnectionProfileRequest,
    CreateConversionWorkspaceRequest,
    CreateMigrationJobRequest,
    CreatePrivateConnectionRequest,
    DeleteConnectionProfileRequest,
    DeleteConversionWorkspaceRequest,
    DeleteMigrationJobRequest,
    DeletePrivateConnectionRequest,
    DescribeConversionWorkspaceRevisionsRequest,
    DescribeConversionWorkspaceRevisionsResponse,
    DescribeDatabaseEntitiesRequest,
    DescribeDatabaseEntitiesResponse,
    FetchStaticIpsRequest,
    FetchStaticIpsResponse,
    GenerateSshScriptRequest,
    GetConnectionProfileRequest,
    GetConversionWorkspaceRequest,
    GetMigrationJobRequest,
    GetPrivateConnectionRequest,
    ImportMappingRulesRequest,
    ListConnectionProfilesRequest,
    ListConnectionProfilesResponse,
    ListConversionWorkspacesRequest,
    ListConversionWorkspacesResponse,
    ListMigrationJobsRequest,
    ListMigrationJobsResponse,
    ListPrivateConnectionsRequest,
    ListPrivateConnectionsResponse,
    OperationMetadata,
    PromoteMigrationJobRequest,
    RestartMigrationJobRequest,
    ResumeMigrationJobRequest,
    RollbackConversionWorkspaceRequest,
    SearchBackgroundJobsRequest,
    SearchBackgroundJobsResponse,
    SeedConversionWorkspaceRequest,
    SshScript,
    StartMigrationJobRequest,
    StopMigrationJobRequest,
    UpdateConnectionProfileRequest,
    UpdateConversionWorkspaceRequest,
    UpdateMigrationJobRequest,
    VerifyMigrationJobRequest,
    VmCreationConfig,
    VmSelectionConfig,
)
from .types.clouddms_resources import (
    AlloyDbConnectionProfile,
    AlloyDbSettings,
    CloudSqlConnectionProfile,
    CloudSqlSettings,
    ConnectionProfile,
    ConversionWorkspaceInfo,
    DatabaseEngine,
    DatabaseProvider,
    DatabaseType,
    ForwardSshTunnelConnectivity,
    MigrationJob,
    MigrationJobVerificationError,
    MySqlConnectionProfile,
    NetworkArchitecture,
    OracleConnectionProfile,
    PostgreSqlConnectionProfile,
    PrivateConnection,
    PrivateConnectivity,
    PrivateServiceConnectConnectivity,
    ReverseSshConnectivity,
    SqlAclEntry,
    SqlIpConfig,
    SslConfig,
    StaticIpConnectivity,
    StaticServiceIpConnectivity,
    VpcPeeringConfig,
    VpcPeeringConnectivity,
)
from .types.conversionworkspace_resources import (
    BackgroundJobLogEntry,
    BackgroundJobType,
    ColumnEntity,
    ConstraintEntity,
    ConversionWorkspace,
    DatabaseEngineInfo,
    DatabaseEntity,
    DatabaseEntityType,
    EntityMapping,
    EntityMappingLogEntry,
    FunctionEntity,
    ImportRulesFileFormat,
    IndexEntity,
    PackageEntity,
    SchemaEntity,
    SequenceEntity,
    StoredProcedureEntity,
    SynonymEntity,
    TableEntity,
    TriggerEntity,
    ViewEntity,
)

__all__ = (
    "DataMigrationServiceAsyncClient",
    "AlloyDbConnectionProfile",
    "AlloyDbSettings",
    "ApplyConversionWorkspaceRequest",
    "BackgroundJobLogEntry",
    "BackgroundJobType",
    "CloudSqlConnectionProfile",
    "CloudSqlSettings",
    "ColumnEntity",
    "CommitConversionWorkspaceRequest",
    "ConnectionProfile",
    "ConstraintEntity",
    "ConversionWorkspace",
    "ConversionWorkspaceInfo",
    "ConvertConversionWorkspaceRequest",
    "CreateConnectionProfileRequest",
    "CreateConversionWorkspaceRequest",
    "CreateMigrationJobRequest",
    "CreatePrivateConnectionRequest",
    "DataMigrationServiceClient",
    "DatabaseEngine",
    "DatabaseEngineInfo",
    "DatabaseEntity",
    "DatabaseEntityType",
    "DatabaseProvider",
    "DatabaseType",
    "DeleteConnectionProfileRequest",
    "DeleteConversionWorkspaceRequest",
    "DeleteMigrationJobRequest",
    "DeletePrivateConnectionRequest",
    "DescribeConversionWorkspaceRevisionsRequest",
    "DescribeConversionWorkspaceRevisionsResponse",
    "DescribeDatabaseEntitiesRequest",
    "DescribeDatabaseEntitiesResponse",
    "EntityMapping",
    "EntityMappingLogEntry",
    "FetchStaticIpsRequest",
    "FetchStaticIpsResponse",
    "ForwardSshTunnelConnectivity",
    "FunctionEntity",
    "GenerateSshScriptRequest",
    "GetConnectionProfileRequest",
    "GetConversionWorkspaceRequest",
    "GetMigrationJobRequest",
    "GetPrivateConnectionRequest",
    "ImportMappingRulesRequest",
    "ImportRulesFileFormat",
    "IndexEntity",
    "ListConnectionProfilesRequest",
    "ListConnectionProfilesResponse",
    "ListConversionWorkspacesRequest",
    "ListConversionWorkspacesResponse",
    "ListMigrationJobsRequest",
    "ListMigrationJobsResponse",
    "ListPrivateConnectionsRequest",
    "ListPrivateConnectionsResponse",
    "MigrationJob",
    "MigrationJobVerificationError",
    "MySqlConnectionProfile",
    "NetworkArchitecture",
    "OperationMetadata",
    "OracleConnectionProfile",
    "PackageEntity",
    "PostgreSqlConnectionProfile",
    "PrivateConnection",
    "PrivateConnectivity",
    "PrivateServiceConnectConnectivity",
    "PromoteMigrationJobRequest",
    "RestartMigrationJobRequest",
    "ResumeMigrationJobRequest",
    "ReverseSshConnectivity",
    "RollbackConversionWorkspaceRequest",
    "SchemaEntity",
    "SearchBackgroundJobsRequest",
    "SearchBackgroundJobsResponse",
    "SeedConversionWorkspaceRequest",
    "SequenceEntity",
    "SqlAclEntry",
    "SqlIpConfig",
    "SshScript",
    "SslConfig",
    "StartMigrationJobRequest",
    "StaticIpConnectivity",
    "StaticServiceIpConnectivity",
    "StopMigrationJobRequest",
    "StoredProcedureEntity",
    "SynonymEntity",
    "TableEntity",
    "TriggerEntity",
    "UpdateConnectionProfileRequest",
    "UpdateConversionWorkspaceRequest",
    "UpdateMigrationJobRequest",
    "VerifyMigrationJobRequest",
    "ViewEntity",
    "VmCreationConfig",
    "VmSelectionConfig",
    "VpcPeeringConfig",
    "VpcPeeringConnectivity",
)
